@@ -619,6 +619,160 @@ metadata:
 `)
 }
 
+func TestHelmChartInflationGeneratorValuesOverride(t *testing.T) {
+	th := kusttest_test.MakeEnhancedHarnessWithTmpRoot(t).
+		PrepBuiltin("HelmChartInflationGenerator")
+	defer th.Reset()
+	if err := th.ErrIfNoHelm(); err != nil {
+		t.Skip("skipping: " + err.Error())
+	}
+
+	copyTestChartsIntoHarness(t, th)
+
+	rm := th.LoadAndRunGenerator(`
+apiVersion: builtin
+kind: HelmChartInflationGenerator
+metadata:
+  name: values-merge
+name: values-merge
+releaseName: values-merge
+valuesMerge: override
+valuesInline:
+  a: 4
+  c: 3
+  list:
+  - c
+  map:
+    a: 7
+    c: 6
+`)
+
+	th.AssertActualEqualsExpected(rm, `
+apiVersion: test.kustomize.io/v1
+kind: ValuesMergeTest
+metadata:
+  name: values-merge
+obj:
+  a: 4
+  b: 2
+  c: 3
+  list:
+  - c
+  map:
+    a: 7
+    b: 5
+    c: 6
+`)
+}
+
+func TestHelmChartInflationGeneratorValuesReplace(t *testing.T) {
+	th := kusttest_test.MakeEnhancedHarnessWithTmpRoot(t).
+		PrepBuiltin("HelmChartInflationGenerator")
+	defer th.Reset()
+	if err := th.ErrIfNoHelm(); err != nil {
+		t.Skip("skipping: " + err.Error())
+	}
+
+	copyTestChartsIntoHarness(t, th)
+
+	th.WriteF(filepath.Join(th.GetRoot(), "replacedValues.yaml"), `
+  a: 7
+  b: 7
+  c: 7
+  list:
+  - g
+  map:
+    a: 7
+    b: 7
+    c: 7
+  `)
+
+	rm := th.LoadAndRunGenerator(`
+apiVersion: builtin
+kind: HelmChartInflationGenerator
+metadata:
+  name: values-merge
+name: values-merge
+releaseName: values-merge
+valuesMerge: replace
+valuesFile: replacedValues.yaml
+valuesInline:
+  a: 1
+  b: 2
+  list:
+  - c
+  map:
+    a: 4
+    b: 5
+`)
+
+	// replace option does not ignore values file from the chart
+	// it only replaces the values files specified in the kustomization
+	th.AssertActualEqualsExpected(rm, `
+apiVersion: test.kustomize.io/v1
+kind: ValuesMergeTest
+metadata:
+  name: values-merge
+obj:
+  a: 1
+  b: 2
+  c: null
+  list:
+  - c
+  map:
+    a: 4
+    b: 5
+    c: null
+`)
+}
+
+func TestHelmChartInflationGeneratorValuesMerge(t *testing.T) {
+	th := kusttest_test.MakeEnhancedHarnessWithTmpRoot(t).
+		PrepBuiltin("HelmChartInflationGenerator")
+	defer th.Reset()
+	if err := th.ErrIfNoHelm(); err != nil {
+		t.Skip("skipping: " + err.Error())
+	}
+
+	copyTestChartsIntoHarness(t, th)
+
+	rm := th.LoadAndRunGenerator(`
+apiVersion: builtin
+kind: HelmChartInflationGenerator
+metadata:
+  name: values-merge
+name: values-merge
+releaseName: values-merge
+valuesMerge: merge
+valuesInline:
+  a: 4
+  c: 3
+  list:
+  - c
+  map:
+    a: 7
+    c: 6
+`)
+
+	th.AssertActualEqualsExpected(rm, `
+apiVersion: test.kustomize.io/v1
+kind: ValuesMergeTest
+metadata:
+  name: values-merge
+obj:
+  a: 1
+  b: 2
+  c: 3
+  list:
+  - a
+  - b
+  map:
+    a: 4
+    b: 5
+    c: 6
+`)
+}
+
 func copyTestChartsIntoHarness(t *testing.T, th *kusttest_test.HarnessEnhanced) {
 	t.Helper()
 
@@ -749,11 +903,11 @@ releaseName: podinfo2
 `)
 
 	podinfo1Img, err := podinfo1.Resources()[1].GetFieldValue("spec.template.spec.containers.0.image")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "ghcr.io/stefanprodan/podinfo:6.2.1", podinfo1Img)
 
 	podinfo2Img, err := podinfo2.Resources()[1].GetFieldValue("spec.template.spec.containers.0.image")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "ghcr.io/stefanprodan/podinfo:6.1.8", podinfo2Img)
 
 	podinfo1ChartsDir := filepath.Join(th.GetRoot(), "charts/podinfo-6.2.1/podinfo")
@@ -763,11 +917,11 @@ releaseName: podinfo2
 	assert.True(t, th.GetFSys().Exists(podinfo2ChartsDir))
 
 	podinfo1ChartContents, err := th.GetFSys().ReadFile(filepath.Join(podinfo1ChartsDir, "Chart.yaml"))
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Contains(t, string(podinfo1ChartContents), "version: 6.2.1")
 
 	podinfo2ChartContents, err := th.GetFSys().ReadFile(filepath.Join(podinfo2ChartsDir, "Chart.yaml"))
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Contains(t, string(podinfo2ChartContents), "version: 6.1.8")
 }
 
@@ -794,14 +948,14 @@ chartHome: ./charts
 `)
 
 	cm, err := rm.Resources()[0].GetFieldValue("metadata.name")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "bar", cm)
 
 	chartDir := filepath.Join(th.GetRoot(), "charts/test-chart")
 	assert.True(t, th.GetFSys().Exists(chartDir))
 
 	chartYamlContent, err := th.GetFSys().ReadFile(filepath.Join(chartDir, "Chart.yaml"))
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Contains(t, string(chartYamlContent), "name: test-chart")
 	assert.Contains(t, string(chartYamlContent), "version: 1.0.0")
 }
